@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #-------------------------------------------------------------------------------
-# $Id: create_instance.py 2203 2012-12-27 16:24:46Z meissls $
+# $Id: create_instance.py 2358 2013-03-15 13:20:17Z meissls $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Fabian Schindler <fabian.schindler@eox.at>
@@ -169,19 +169,23 @@ class Command(EOxServerAdminCommand):
                 from pyspatialite import dbapi2 as db
                 conn = db.connect(db_name)
                 rs = conn.execute('SELECT spatialite_version()')
-                if int(rs.fetchone()[0].split(".")[0]) < 3:
-                    init_sql_path = os.path.join(src_conf_dir, "init_spatialite-2.3.sql")
-                    os.system("spatialite %s < %s" % (db_name, init_sql_path))
-                else:
+                rs = rs.fetchone()[0].split(".")
+                if (int(rs[0]), int(rs[1])) >= (2, 4):
+                    print("SpatiaLite found, initializing using 'InitSpatialMetadata()'.")
                     conn.execute("SELECT InitSpatialMetadata()")
+                else:
+                    print("SpatiaLite version <2.4 found, trying to initialize using 'init_spatialite-2.3.sql'.")
+                    init_sql_path = os.path.join(src_conf_dir, "init_spatialite-2.3.sql")
+                    with open(init_sql_path, 'r') as init_sql_file:
+                        conn.executescript(init_sql_file.read())
                 conn.commit()
                 conn.close()
             except ImportError:
+                print("SpatiaLite not found, trying to initialize using 'init_spatialite-2.3.sql'.")
                 init_sql_path = os.path.join(src_conf_dir, "init_spatialite-2.3.sql")
                 os.system("spatialite %s < %s" % (db_name, init_sql_path))
 
 
-# TODO maybe use django templating library?
 def copy_and_replace_tags(src_pth, dst_pth, replacements={}):
     """Helper function to copy a file and replace tags within a file."""
     new_file = open(dst_pth,'w')
