@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# $Id: covmgrs.py 1987 2012-08-28 14:26:19Z schindlerf $
+# $Id: covmgrs.py 2418 2013-04-03 17:34:50Z martin.paces $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -51,7 +51,7 @@ from eoxserver.core.util.timetools import UTCOffsetTimeZoneInfo
 from eoxserver.resources.coverages.interfaces import ManagerInterface
 from eoxserver.resources.coverages.exceptions import (
     ManagerError, NoSuchCoverageException, CoverageIdReservedError,
-    CoverageIdInUseError, CoverageIdReleaseError
+    CoverageIdInUseError, CoverageIdReleaseError, MetadataException
 )
 from eoxserver.resources.coverages.models import (
     PlainCoverageRecord, RectifiedDatasetRecord, 
