@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# $Id: eoxs_register_dataset.py 1656 2012-05-04 09:20:07Z schindlerf $
+# $Id: eoxs_register_dataset.py 2055 2012-10-11 07:32:13Z schindlerf $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -41,7 +41,6 @@ from eoxserver.core.system import System
 from eoxserver.core.util.geotools import extentFromDataset
 from eoxserver.core.util.timetools import getDateTime
 from eoxserver.resources.coverages.geo import GeospatialMetadata
-from eoxserver.resources.coverages.exceptions import MetadataException
 from eoxserver.resources.coverages.management.commands import (
     CommandOutputMixIn, _variable_args_cb, StringFormatCallback
 )
@@ -188,9 +187,10 @@ class Command(CommandOutputMixIn, BaseCommand):
         ),
         make_option('--visible',
             dest='visible',
-            default=True,
-            help=("Optional. Sets the visibility status of all datasets to the"
-                  "given boolean value. Defaults to 'True'.")
+            metavar='TRUE_OR_FALSE',
+            default="True",
+            help=("Optional. Sets the visibility status of all datasets to the "
+                  "given boolean ('True' or 'False') value. Defaults to 'True'.")
         )
     )
     
@@ -265,7 +265,15 @@ class Command(CommandOutputMixIn, BaseCommand):
         default_begin_time = options.get("default_begin_time")
         default_end_time = options.get("default_end_time")
         default_footprint = options.get("default_footprint")
-        visible = options.get("visible", True)
+        
+        visible = options.get("visible", "True").lower()
+        if visible in ("true", "yes", "y"):
+            visible = True
+        elif visible in ("false", "no", "n"):
+            visible = False
+        else:
+            raise CommandError("Wrong value for '--visible' flag. Use 'True' "
+                               "or 'False'.")
         
         datasetseries_eoids = options.get('datasetseries_eoids', [])
         stitchedmosaic_eoids = options.get('stitchedmosaic_eoids', [])
@@ -389,10 +397,12 @@ class Command(CommandOutputMixIn, BaseCommand):
         # Execute creation and insertion
         #=======================================================================
         
+        error_count = 0 # error counter - counts failed inserts 
+
         for df, mdf, cid in zip(datafiles, metadatafiles, coverageids):
             self.print_msg("Inserting coverage with ID '%s'." % cid, 2)
             
-            args = {
+            mgrargs = {
                 "obj_id": cid,
                 "range_type_name": rangetype,
                 "default_srid": default_srid,
@@ -407,7 +417,7 @@ class Command(CommandOutputMixIn, BaseCommand):
             
             if mode == 'local':
                 self.print_msg("\tFile: '%s'\n\tMeta-data: '%s'" % (df, mdf), 2)
-                args.update({
+                mgrargs.update({
                     "local_path": df,
                     "md_local_path": mdf,
                 })
@@ -418,7 +428,7 @@ class Command(CommandOutputMixIn, BaseCommand):
             
             elif mode == 'ftp':
                 self.print_msg("\tFile: '%s'\n\tMeta-data: '%s'" % (df, mdf), 2)
-                args.update({
+                mgrargs.update({
                     "remote_path": df,
                     "md_remote_path": mdf,
                     
@@ -439,7 +449,7 @@ class Command(CommandOutputMixIn, BaseCommand):
                     ), 2
                 )
                 
-                args.update({
+                mgrargs.update({
                     "collection": df,
                     "oid": oid,
                     "md_local_path": mdf,
@@ -469,7 +479,7 @@ class Command(CommandOutputMixIn, BaseCommand):
                     pass
             
             if geo_metadata is not None:
-                args["geo_metadata"] = geo_metadata
+                mgrargs["geo_metadata"] = geo_metadata
                 
                 if geo_metadata.is_referenceable:
                     ref_mgr = System.getRegistry().findAndBind(
@@ -482,30 +492,46 @@ class Command(CommandOutputMixIn, BaseCommand):
                     self.print_msg("\t'%s' is referenceable." % df, 2)
             
             if eo_metadata is not None:
-                # we cannot check at this point whether or not the file exists 
-                # on FTP. So we assume it does.
-                if mode != "ftp" and not os.path.exists(mdf):
-                    if eo_metadata.footprint is None:
-                        raise CommandError("Default footprint could not be determined.")
-                    if eo_metadata.begin_time is None:
-                        raise CommandError("No default begin time given.")
-                    if eo_metadata.end_time is None:
-                        raise CommandError("No default end time given.")
-                
-                    args["eo_metadata"] = eo_metadata
+                if eo_metadata.footprint is None:
+                    raise CommandError("Default footprint could not be determined.")
+                if eo_metadata.begin_time is None:
+                    raise CommandError("No default begin time given.")
+                if eo_metadata.end_time is None:
+                    raise CommandError("No default end time given.")
+            
+                mgrargs["eo_metadata"] = eo_metadata
                 
+
             try:
+
                 with transaction.commit_on_success():
-                    mgr_to_use.create(**args)
-            except MetadataException, e: #TODO here
-                self.print_msg(
-                    "ERROR: registration of dataset failed, message was '%s'" % str(e),
-                    1, error=True
-                )
+
+                    mgr_to_use.create(**mgrargs)
+
+            except Exception as e: 
+
                 if options.get("traceback", False):
                     self.print_msg(traceback.format_exc())
+
+                self.print_msg( "ERROR: Registration of dataset '%s' failed!"
+                    " %s: %s"%(cid, type(e).__name__, str(e)), 1, error=True)
+
+                error_count += 1 
+
+                continue # continue by next dataset 
+
+        #=======================================================================
+        # print the final info 
         
-        self.print_msg("Successfully inserted %d dataset%s." % (
-                len(datafiles), "s" if len(datafiles) > 1 else ""
-            )
-        )
+        count = len(datafiles) 
+        success_count = count - error_count
+
+        if ( error_count > 0 ) : 
+            self.print_msg( "Failed to insert %d dataset%s." % (
+                error_count , ("","s")[error_count!=1] ) )  
+
+        if ( success_count > 0 ) : 
+            self.print_msg( "Successfully inserted %d of %s dataset%s." % (
+                success_count , count , ("","s")[count!=1] ) )
+        else : 
+            self.print_msg( "No dataset inserted successfully." ) 
