@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------
-# $Id: wrappers.py 1640 2012-04-19 10:31:48Z schindlerf $
+# $Id: wrappers.py 2352 2013-03-15 09:38:10Z meissls $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -1510,8 +1510,14 @@ class DatasetSeriesWrapper(EOMetadataWrapper, ResourceWrapper):
             self.__block_md_update = False
     
     def _aggregateMetadata(self, eo_metadata_set):
-        begin_time = min(eo_metadata_set.values_list('timestamp_begin', flat=True))
-        end_time = max(eo_metadata_set.values_list('timestamp_end', flat=True))
+        try:
+            begin_time = min(eo_metadata_set.values_list('timestamp_begin', flat=True))
+            end_time = max(eo_metadata_set.values_list('timestamp_end', flat=True))
+        # Work around for issue in Django 1.5
+        except TypeError:
+            begin_time = min([t.timestamp_begin for t in eo_metadata_set])
+            end_time = max([t.timestamp_end for t in eo_metadata_set])
+        
         footprint = eo_metadata_set.aggregate(
             Union('footprint')
         )["footprint__union"]
