@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# $Id: getcov.py 1794 2012-06-29 16:05:01Z martin.paces $
+# $Id: getcov.py 2081 2012-10-22 15:52:26Z martin.paces $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -158,20 +158,20 @@ class WCS20GetReferenceableCoverageHandler(BaseRequestHandler):
             )
         
         if subset is None:
+
             x_off = 0
             y_off = 0
             x_size = cov_x_size
             y_size = cov_y_size
+
         elif subset.crs_id != "imageCRS":
+
             x_off, y_off, x_size, y_size = rect_from_subset(
-                coverage.getData().getGDALDatasetIdentifier(),
-                subset.crs_id,
-                subset.minx,
-                subset.miny,
-                subset.maxx,
-                subset.maxy
-            )
+                coverage.getData().getGDALDatasetIdentifier(), subset.crs_id,
+                subset.minx, subset.miny, subset.maxx, subset.maxy )
+
         else:
+
             x_off = subset.minx
             y_off = subset.miny
             x_size = subset.maxx - subset.minx + 1
@@ -266,15 +266,15 @@ class WCS20GetReferenceableCoverageHandler(BaseRequestHandler):
         # save GCPs
         src_gcp_proj = src_ds.GetGCPProjection()
         src_gcps = src_ds.GetGCPs()
-        
+
         dst_gcps = []
         for src_gcp in src_gcps:
             dst_gcps.append(gdal.GCP(
                 src_gcp.GCPX,
                 src_gcp.GCPY,
                 src_gcp.GCPZ,
-                src_gcp.GCPPixel + src_x_off - dst_x_off,
-                src_gcp.GCPLine + src_y_off - dst_y_off,
+                src_gcp.GCPPixel - src_x_off + dst_x_off,
+                src_gcp.GCPLine - src_y_off + dst_y_off,
                 src_gcp.Info,
                 src_gcp.Id
             ))
@@ -317,7 +317,8 @@ class WCS20GetReferenceableCoverageHandler(BaseRequestHandler):
                     _subset = ( subset.crs_id, (x_size, y_size),
                         (subset.minx, subset.miny, subset.maxx, subset.maxy), footprint ) 
 
-            cov_desc_el = encoder.encodeReferenceableDataset(coverage,reference,mime_type,True,_subset)
+            cov_desc_el = encoder.encodeReferenceableDataset(coverage,
+                            "cid:%s"%reference,mime_type,True,_subset)
             
             # NOTE: the multipart subtype will be the same as the one requested 
             resp = self._get_multipart_response( dst_filename, reference , 
