@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# $Id: common.py 1492 2012-03-09 11:21:56Z schindlerf $
+# $Id: common.py 2135 2012-11-22 17:28:13Z meissls $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -283,7 +283,7 @@ class WMSDatasetSeriesLayer(WMSLayer):
         layer.setExtent(*self.dataset_series.getWGS84Extent())
         
         time_extent = ",".join(
-            [isotime(coverage.getBeginTime()) for coverage in coverages]
+            sorted(set(isotime(coverage.getBeginTime()) for coverage in coverages))
         )
         layer.setMetaData("wms_timeextent", time_extent)
         
